@@ -171,7 +171,7 @@ class PrEvent(Document):
     repo_type = StringField()
     category = DictField()
     file_count = DictField()
-    tokens = DictField()
+    tokens = ListField()
     files = ListField()
     omitted_files = ListField()
 
